/*
 * APISampleJavaView.java
 */

package apisamplejava;

import com.premiereconnect.premconn._2007._02.JobSubmitRequest;
import javax.xml.ws.BindingProvider;
import org.jdesktop.application.Action;
import org.jdesktop.application.ResourceMap;
import org.jdesktop.application.SingleFrameApplication;
import org.jdesktop.application.FrameView;
import org.jdesktop.application.TaskMonitor;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.List;
import java.util.ListIterator;
import javax.swing.Timer;
import javax.swing.Icon;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JOptionPane;



/**
 * The application's main frame.
 */
public class APISampleJavaView extends FrameView {

    public APISampleJavaView(SingleFrameApplication app) {
        super(app);

        initComponents();

        // status bar initialization - message timeout, idle icon and busy animation, etc
        ResourceMap resourceMap = getResourceMap();
        int messageTimeout = resourceMap.getInteger("StatusBar.messageTimeout");
        messageTimer = new Timer(messageTimeout, new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                statusMessageLabel.setText("");
            }
        });
        messageTimer.setRepeats(false);
        int busyAnimationRate = resourceMap.getInteger("StatusBar.busyAnimationRate");
        for (int i = 0; i < busyIcons.length; i++) {
            busyIcons[i] = resourceMap.getIcon("StatusBar.busyIcons[" + i + "]");
        }
        busyIconTimer = new Timer(busyAnimationRate, new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                busyIconIndex = (busyIconIndex + 1) % busyIcons.length;
                statusAnimationLabel.setIcon(busyIcons[busyIconIndex]);
            }
        });
        idleIcon = resourceMap.getIcon("StatusBar.idleIcon");
        statusAnimationLabel.setIcon(idleIcon);
        progressBar.setVisible(false);

        // connecting action tasks to status bar via TaskMonitor
        TaskMonitor taskMonitor = new TaskMonitor(getApplication().getContext());
        taskMonitor.addPropertyChangeListener(new java.beans.PropertyChangeListener() {
            public void propertyChange(java.beans.PropertyChangeEvent evt) {
                String propertyName = evt.getPropertyName();
                if ("started".equals(propertyName)) {
                    if (!busyIconTimer.isRunning()) {
                        statusAnimationLabel.setIcon(busyIcons[0]);
                        busyIconIndex = 0;
                        busyIconTimer.start();
                    }
                    progressBar.setVisible(true);
                    progressBar.setIndeterminate(true);
                } else if ("done".equals(propertyName)) {
                    busyIconTimer.stop();
                    statusAnimationLabel.setIcon(idleIcon);
                    progressBar.setVisible(false);
                    progressBar.setValue(0);
                } else if ("message".equals(propertyName)) {
                    String text = (String)(evt.getNewValue());
                    statusMessageLabel.setText((text == null) ? "" : text);
                    messageTimer.restart();
                } else if ("progress".equals(propertyName)) {
                    int value = (Integer)(evt.getNewValue());
                    progressBar.setVisible(true);
                    progressBar.setIndeterminate(false);
                    progressBar.setValue(value);
                }
            }
        });
    }

    @Action
    public void showAboutBox() {
        if (aboutBox == null) {
            JFrame mainFrame = APISampleJavaApp.getApplication().getMainFrame();
            aboutBox = new APISampleJavaAboutBox(mainFrame);
            aboutBox.setLocationRelativeTo(mainFrame);
        }
        APISampleJavaApp.getApplication().show(aboutBox);
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        mainPanel = new javax.swing.JPanel();
        jTextUSER = new javax.swing.JTextField();
        jTextPASS = new javax.swing.JTextField();
        jLabel1 = new javax.swing.JLabel();
        jLabel2 = new javax.swing.JLabel();
        jButton1 = new javax.swing.JButton();
        jComboService = new javax.swing.JComboBox();
        jTextPhone1 = new javax.swing.JTextField();
        jLabel3 = new javax.swing.JLabel();
        jLabel4 = new javax.swing.JLabel();
        menuBar = new javax.swing.JMenuBar();
        javax.swing.JMenu fileMenu = new javax.swing.JMenu();
        javax.swing.JMenuItem exitMenuItem = new javax.swing.JMenuItem();
        javax.swing.JMenu helpMenu = new javax.swing.JMenu();
        javax.swing.JMenuItem aboutMenuItem = new javax.swing.JMenuItem();
        statusPanel = new javax.swing.JPanel();
        javax.swing.JSeparator statusPanelSeparator = new javax.swing.JSeparator();
        statusMessageLabel = new javax.swing.JLabel();
        statusAnimationLabel = new javax.swing.JLabel();
        progressBar = new javax.swing.JProgressBar();
        jFrame1 = new javax.swing.JFrame();

        mainPanel.setName("mainPanel"); // NOI18N

        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance(apisamplejava.APISampleJavaApp.class).getContext().getResourceMap(APISampleJavaView.class);
        jTextUSER.setText(resourceMap.getString("txtUser.text")); // NOI18N
        jTextUSER.setName("txtUser"); // NOI18N

        jTextPASS.setText(resourceMap.getString("txtPass.text")); // NOI18N
        jTextPASS.setName("txtPass"); // NOI18N

        jLabel1.setText(resourceMap.getString("jLabel1.text")); // NOI18N
        jLabel1.setName("jLabel1"); // NOI18N

        jLabel2.setText(resourceMap.getString("jLabel2.text")); // NOI18N
        jLabel2.setName("jLabel2"); // NOI18N

        javax.swing.ActionMap actionMap = org.jdesktop.application.Application.getInstance(apisamplejava.APISampleJavaApp.class).getContext().getActionMap(APISampleJavaView.class, this);
        jButton1.setAction(actionMap.get("AuthenticateUser")); // NOI18N
        jButton1.setText(resourceMap.getString("btnAuthenticate.text")); // NOI18N
        jButton1.setName("btnAuthenticate"); // NOI18N
        jButton1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jButton1ActionPerformed(evt);
            }
        });

        jComboService.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Pre-Production", "Test2" }));
        jComboService.setName("jComboService"); // NOI18N

        jTextPhone1.setName("jTextPhone1"); // NOI18N

        jLabel3.setText(resourceMap.getString("jLabel3.text")); // NOI18N
        jLabel3.setName("jLabel3"); // NOI18N

        jLabel4.setText(resourceMap.getString("jLabel4.text")); // NOI18N
        jLabel4.setName("jLabel4"); // NOI18N

        javax.swing.GroupLayout mainPanelLayout = new javax.swing.GroupLayout(mainPanel);
        mainPanel.setLayout(mainPanelLayout);
        mainPanelLayout.setHorizontalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(mainPanelLayout.createSequentialGroup()
                .addGap(65, 65, 65)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(jLabel4)
                    .addComponent(jLabel1)
                    .addComponent(jLabel3)
                    .addComponent(jLabel2))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(mainPanelLayout.createSequentialGroup()
                        .addComponent(jComboService, javax.swing.GroupLayout.PREFERRED_SIZE, 167, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED))
                    .addGroup(mainPanelLayout.createSequentialGroup()
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(jTextUSER, javax.swing.GroupLayout.DEFAULT_SIZE, 96, Short.MAX_VALUE)
                            .addComponent(jTextPASS, javax.swing.GroupLayout.DEFAULT_SIZE, 96, Short.MAX_VALUE)
                            .addComponent(jTextPhone1, javax.swing.GroupLayout.DEFAULT_SIZE, 96, Short.MAX_VALUE))
                        .addGap(71, 71, 71)))
                .addGap(33, 33, 33)
                .addComponent(jButton1)
                .addContainerGap())
        );
        mainPanelLayout.setVerticalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(mainPanelLayout.createSequentialGroup()
                .addGap(34, 34, 34)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jComboService, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel4))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel1)
                    .addComponent(jTextUSER, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jTextPASS, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel2))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jTextPhone1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jButton1)
                    .addComponent(jLabel3))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        menuBar.setName("menuBar"); // NOI18N

        fileMenu.setText(resourceMap.getString("fileMenu.text")); // NOI18N
        fileMenu.setName("fileMenu"); // NOI18N

        exitMenuItem.setAction(actionMap.get("quit")); // NOI18N
        exitMenuItem.setName("exitMenuItem"); // NOI18N
        fileMenu.add(exitMenuItem);

        menuBar.add(fileMenu);

        helpMenu.setText(resourceMap.getString("helpMenu.text")); // NOI18N
        helpMenu.setName("helpMenu"); // NOI18N

        aboutMenuItem.setAction(actionMap.get("showAboutBox")); // NOI18N
        aboutMenuItem.setName("aboutMenuItem"); // NOI18N
        helpMenu.add(aboutMenuItem);

        menuBar.add(helpMenu);

        statusPanel.setName("statusPanel"); // NOI18N

        statusPanelSeparator.setName("statusPanelSeparator"); // NOI18N

        statusMessageLabel.setName("statusMessageLabel"); // NOI18N

        statusAnimationLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        statusAnimationLabel.setName("statusAnimationLabel"); // NOI18N

        progressBar.setName("progressBar"); // NOI18N

        javax.swing.GroupLayout statusPanelLayout = new javax.swing.GroupLayout(statusPanel);
        statusPanel.setLayout(statusPanelLayout);
        statusPanelLayout.setHorizontalGroup(
            statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(statusPanelSeparator, javax.swing.GroupLayout.DEFAULT_SIZE, 389, Short.MAX_VALUE)
            .addGroup(statusPanelLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(statusMessageLabel)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 219, Short.MAX_VALUE)
                .addComponent(progressBar, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(statusAnimationLabel)
                .addContainerGap())
        );
        statusPanelLayout.setVerticalGroup(
            statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(statusPanelLayout.createSequentialGroup()
                .addComponent(statusPanelSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 2, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addGroup(statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(statusMessageLabel)
                    .addComponent(statusAnimationLabel)
                    .addComponent(progressBar, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(3, 3, 3))
        );

        jFrame1.setName("jFrame1"); // NOI18N

        javax.swing.GroupLayout jFrame1Layout = new javax.swing.GroupLayout(jFrame1.getContentPane());
        jFrame1.getContentPane().setLayout(jFrame1Layout);
        jFrame1Layout.setHorizontalGroup(
            jFrame1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 400, Short.MAX_VALUE)
        );
        jFrame1Layout.setVerticalGroup(
            jFrame1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 300, Short.MAX_VALUE)
        );

        setComponent(mainPanel);
        setMenuBar(menuBar);
        setStatusBar(statusPanel);
    }// </editor-fold>//GEN-END:initComponents

    private void jButton1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButton1ActionPerformed
        // TODO add your handling code here:


    }//GEN-LAST:event_jButton1ActionPerformed

    public String SetURL() {
        // Get the value of the service from the pull down combo box
        if (jComboService.getSelectedItem().equals("Test2")) {
            // Use the Test2 system
            return "http://test2api.pgiconnect.com/soap/sync";
        }
        else {
            // Use the Pre-Production PT system
            return "http://xoa.pt.premiereglobal.com/soap/sync";
        }

    }

    @Action
    public void AuthenticateUser() {
        try { // Call Web Service Operation
            // Create XOA Service Object and Port (NOTE: This is from the PGiConnect Web Service imported
            // as a WebService Reference
            com.premiereconnect.premconn._2007._02.XOA service = new com.premiereconnect.premconn._2007._02.XOA();
            com.premiereconnect.premconn._2007._02.XOASOAPPort port = service.getXOAPort();

            // set all types needed
            com.premiereconnect.premconn._2007._02.MessageType JobMessage = new com.premiereconnect.premconn._2007._02.MessageType();
            com.premiereconnect.premconn._2007._02.JobOptionsType JobOptions = new com.premiereconnect.premconn._2007._02.JobOptionsType();
            com.premiereconnect.premconn._2007._02.FaxOptionsType FaxOptionsType = new com.premiereconnect.premconn._2007._02.FaxOptionsType();          
            com.premiereconnect.premconn._2007._02.DestinationType DestinationType = new com.premiereconnect.premconn._2007._02.DestinationType();
            com.premiereconnect.premconn._2007._02.ReportOptionsType ReportOptionsType = new com.premiereconnect.premconn._2007._02.ReportOptionsType();
            com.premiereconnect.premconn._2007._02.ReportOptionsType.DeliveryReport DeliveryReport = new com.premiereconnect.premconn._2007._02.ReportOptionsType.DeliveryReport();
            com.premiereconnect.premconn._2007._02.DocumentType DocumentType = new com.premiereconnect.premconn._2007._02.DocumentType();
            com.premiereconnect.premconn._2007._02.DocDataType DocDataType = new com.premiereconnect.premconn._2007._02.DocDataType();
            com.premiereconnect.premconn._2007._02.ContentsType ContentsType = new com.premiereconnect.premconn._2007._02.ContentsType();
            com.premiereconnect.premconn._2007._02.ContentPartType ContentPartType = new com.premiereconnect.premconn._2007._02.ContentPartType();
            com.premiereconnect.premconn._2007._02.DocumentSetType DocumentSetType = new com.premiereconnect.premconn._2007._02.DocumentSetType();
            com.premiereconnect.premconn._2007._02.DeliveryItemListType ItemType = new com.premiereconnect.premconn._2007._02.DeliveryItemListType();


            //com.premiereconnect.premconn._2007._02.Destinations
            com.premiereconnect.premconn._2007._02.FaxType FaxType = new com.premiereconnect.premconn._2007._02.FaxType();
            
         // Initialize WebService objects
            //com.premiereconnect.premconn._2007._02.AuthenticateRequest parameter = new com.premiereconnect.premconn._2007._02.AuthenticateRequest();
            com.premiereconnect.premconn._2007._02.Request requestHeader = new com.premiereconnect.premconn._2007._02.Request();
            //javax.xml.ws.Holder<com.premiereconnect.premconn._2007._02.AuthenticateResult> parameter0 = new javax.xml.ws.Holder<com.premiereconnect.premconn._2007._02.AuthenticateResult>();
            javax.xml.ws.Holder<com.premiereconnect.premconn._2007._02.Response> responseHeader = new javax.xml.ws.Holder<com.premiereconnect.premconn._2007._02.Response>();
            // Initialize WebService objects
            JobSubmitRequest parameterJobSubmitRequest = new com.premiereconnect.premconn._2007._02.JobSubmitRequest();
            parameterJobSubmitRequest.setDocumentSet(DocumentSetType);

            javax.xml.ws.Holder<com.premiereconnect.premconn._2007._02.JobSubmitResult> parameterJobSubmitResult = new javax.xml.ws.Holder<com.premiereconnect.premconn._2007._02.JobSubmitResult>();

          //___________________________________

            //parameterJobSubmitRequest.getMessage().
            JobMessage.setJobOptions(JobOptions);

            DestinationType.setType(com.premiereconnect.premconn._2007._02.AddressType.FAX);
            JobOptions.setFaxOptions(FaxOptionsType);
            JobMessage.setDestinations(ItemType);

            String Phone;

            Phone = (jTextPhone1.getText());
            FaxType.setPhone(Phone);

            //Inserts the information into the destination element of the XML
            ItemType.getListOrSmQueryOrTable().add(FaxType);
            DocumentType.setDocData(DocDataType);
            JobMessage.setContents(ContentsType);
            DocDataType.setFormat(com.premiereconnect.premconn._2007._02.DocEncodingFormat.TEXT);
            ContentPartType.setDocument(DocumentType);
            ContentsType.getPart().add(ContentPartType);
            DocumentType.setDocType("text");
            DocDataType.setValue("This is a test of a Java Fax Job Submit!");

            JobMessage.setReports(ReportOptionsType);
            DeliveryReport.setDeliveryReportType(com.premiereconnect.premconn._2007._02.MainReportTypeEnum.DETAIL);
            ReportOptionsType.setDeliveryReport(DeliveryReport);


 
            //DocumentSetType.getDocument().add(DocumentType);

            // Need to Adjust the Submit URL becuase the one listed in the WSDL Port Binding
            // is not a valid reference.  The WSDL uses xoa.xpedite.com however this is not a valid
            // submit URL a valid one isn't posted becuase PGiConnect has several valid submit URL's
            BindingProvider bp = (BindingProvider)port;
            String address = (String)bp.getRequestContext().get(BindingProvider.ENDPOINT_ADDRESS_PROPERTY);
            address = SetURL();  // Set URL returns a string value of the submit URL
            bp.getRequestContext().put(BindingProvider.ENDPOINT_ADDRESS_PROPERTY, address);

            // Setup XDDSAuth object
            com.premiereconnect.premconn._2007._02.XDDSAuthType XDDSAuth = new com.premiereconnect.premconn._2007._02.XDDSAuthType();
            XDDSAuth.setPassword(jTextPASS.getText());      // GetPassword from textbox
            XDDSAuth.setRequesterID(jTextUSER.getText());   // GetUser from textbox

          // Setup and Assign Authentication Object
            com.premiereconnect.premconn._2007._02.Authentication Auth = new com.premiereconnect.premconn._2007._02.Authentication();
            Auth.setXDDSAuth(XDDSAuth);


            // Set Header Tags
            requestHeader.setAuthentication(Auth);  // Authentication in Header
            requestHeader.setReceiverKey(SetURL()); // Receiver Key in Header
           


            parameterJobSubmitRequest.getMessage().add(JobMessage);

            // Make Jobsubmit call
            port.jobSubmit(parameterJobSubmitRequest, requestHeader, parameterJobSubmitResult, responseHeader);
            //String JSR;


            // Check Status code of the result
            int StatusCode = parameterJobSubmitResult.value.getStatus().getStatusCode().intValue();

            List<com.premiereconnect.premconn._2007._02.MessageResultType> msgResultList = parameterJobSubmitResult.value.getMessageResult();

            ListIterator<com.premiereconnect.premconn._2007._02.MessageResultType> msgResultIter = msgResultList.listIterator();

            String domain = null;
            String jobNumber = null;

            while(msgResultIter.hasNext())
            {
            com.premiereconnect.premconn._2007._02.MessageResultType msgResult = msgResultIter.next();

            com.premiereconnect.premconn._2007._02.JobIdType jobId = msgResult.getJobId();
            domain = jobId.getXDN();
            jobNumber = jobId.getMRN().toString();
            }

            String processingID;


            if ( StatusCode == 0) {
                // StatusCode 0 = JobSubmit Successful
               processingID = responseHeader.value.getProcessingID();
               JOptionPane.showMessageDialog(null, "Successful Job Submit!!! " + "\n" + "Domain " + domain + " " + "\n" + "Job Number " + jobNumber + "\n" + " " + "Processing ID " + processingID);
            }
            else
            {
                // JobSubmit Error (Display error in MsgBox)
                String sError = parameterJobSubmitResult.value.getStatus().getStatusCode().toString();
                sError += "\n" + parameterJobSubmitResult.value.getStatus().getStatusMessage();
                JOptionPane.showMessageDialog(null, sError);
            }

            } catch (Exception ex) {
            // TODO handle custom exceptions here
            System.out.print(ex.getMessage());
        }

    }




    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton jButton1;
    private javax.swing.JComboBox jComboService;
    private javax.swing.JFrame jFrame1;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JTextField jTextPASS;
    private javax.swing.JTextField jTextPhone1;
    private javax.swing.JTextField jTextUSER;
    private javax.swing.JPanel mainPanel;
    private javax.swing.JMenuBar menuBar;
    private javax.swing.JProgressBar progressBar;
    private javax.swing.JLabel statusAnimationLabel;
    private javax.swing.JLabel statusMessageLabel;
    private javax.swing.JPanel statusPanel;
    // End of variables declaration//GEN-END:variables

    private final Timer messageTimer;
    private final Timer busyIconTimer;
    private final Icon idleIcon;
    private final Icon[] busyIcons = new Icon[15];
    private int busyIconIndex = 0;

    private JDialog aboutBox;
}
